@@ -112,7 +112,6 @@ static void
 set_lang (void)
 {
   const char *gdm_lang;
-  char       *env_string;
   char       *short_lang;
   char       *p;
 
@@ -124,14 +123,10 @@ set_lang (void)
       if (p)
 	*p = '\0';
 
-      env_string = g_strconcat ("LANG=", gdm_lang, NULL);
-      putenv (env_string);
+      g_setenv ("LANG", gdm_lang, TRUE);
 
-      /* env_string = g_strconcat ("LANGUAGE=", short_lang, NULL);
-      putenv (env_string); */
-
-      /* env_string = g_strconcat ("LC_ALL=", gdm_lang, NULL);
-      putenv (env_string); */
+      /* g_setenv ("LANGUAGE", short_lang, TRUE); */
+      /* g_setenv ("LC_ALL", gdm_lang, TRUE); */
 
       g_free (short_lang);
     }
@@ -229,7 +224,7 @@ check_for_dns (void)
       if (getaddrinfo (hostname, NULL, &hints, &result) != 0)
 	return FALSE;
 
-      if (g_ascii_strncasecmp (result->ai_canonname, hostname, 0) != 0)
+      if (!result->ai_canonname)
 	return FALSE;
     } 
   else
@@ -280,11 +275,11 @@ gnome_login_check (void)
       gtk_dialog_set_default_response (GTK_DIALOG (tmp_msgbox), RESPONSE_TRY_AGAIN);
 
       if (RESPONSE_TRY_AGAIN != gtk_dialog_run (GTK_DIALOG (tmp_msgbox)))
-	{
-	  gtk_widget_destroy (tmp_msgbox);
-  	  break;
-	}
+	break;
     }
+
+    if (tmp_msgbox)
+	gtk_widget_destroy (tmp_msgbox);
 }
 
 static void
@@ -332,13 +327,13 @@ main (int argc, char *argv[])
   char *ep;
   char *session_name_env;
   Session *the_session;
-  GConfClient *gconf_client;
   gboolean splashing;
   gboolean a_t_support;
   GError *err;
   int status;
   char *display_str;
   char **versions;
+  GConfClient *gconf_client;
   
   if (getenv ("GSM_VERBOSE_DEBUG"))
     gsm_set_verbose (TRUE);
@@ -396,7 +391,7 @@ main (int argc, char *argv[])
     }
   
   /* Read the config option early, so that we know if a11y is set or not */ 
-  gconf_client = gconf_client_get_default ();
+  gconf_client = gsm_get_conf_client ();
   gconf_client_add_dir (gconf_client, GSM_GCONF_CONFIG_PREFIX, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL); 
   a_t_support = gconf_client_get_bool (gconf_client, ACCESSIBILITY_KEY, NULL);
 
@@ -451,8 +446,6 @@ main (int argc, char *argv[])
 			   update_boolean,
 			   &logout_prompt, NULL, NULL);
 
-  g_object_unref (gconf_client);
-
   gnome_config_push_prefix (GSM_OPTION_CONFIG_PREFIX);
 
   /* If the session wasn't set on the command line, but we see a
@@ -502,7 +495,8 @@ main (int argc, char *argv[])
   gsm_sound_logout ();
 
   gsm_keyring_daemon_stop ();
-  
+
+  g_object_unref (gconf_client);
   gsm_shutdown_gconfd ();
 
   clean_ice ();
